@@ -1,7 +1,5 @@
 import pyparsing as pp
 
-from pydbml.classes import Table
-
 from .column import table_column
 from .common import _
 from .common import _c
@@ -10,8 +8,9 @@ from .common import note
 from .common import note_object
 from .generic import name
 from .index import indexes
+from pydbml.parser.blueprints import TableBlueprint
 
-pp.ParserElement.setDefaultWhitespaceChars(' \t\r')
+pp.ParserElement.set_default_whitespace_chars(' \t\r')
 
 alias = pp.WordStart() + pp.Literal('as').suppress() - pp.WordEnd() - name
 
@@ -26,19 +25,19 @@ table_setting = _ + (note('note') | header_color) + _
 table_settings = '[' + table_setting + (',' + table_setting)[...] + ']'
 
 
-def parse_table_settings(s, l, t):
+def parse_table_settings(s, loc, tok):
     '''
     [headercolor: #cccccc, note: 'note']
     '''
     result = {}
-    if 'note' in t:
-        result['note'] = t['note']
-    if 'header_color' in t:
-        result['header_color'] = t['header_color']
+    if 'note' in tok:
+        result['note'] = tok['note']
+    if 'header_color' in tok:
+        result['header_color'] = tok['header_color']
     return result
 
 
-table_settings.setParseAction(parse_table_settings)
+table_settings.set_parse_action(parse_table_settings)
 
 
 note_element = note | note_object
@@ -47,16 +46,18 @@ table_element = _ + (note_element('note') | indexes('indexes')) + _
 
 table_body = table_column[1, ...]('columns') + _ + table_element[...]
 
+table_name = (name('schema') + '.' + name('name')) | (name('name'))
+
 table = _c + (
     pp.CaselessLiteral("table").suppress()
-    + name('name')
+    + table_name
     + alias('alias')[0, 1]
     + table_settings('settings')[0, 1] + _
     + '{' - table_body + _ + '}'
 ) + end
 
 
-def parse_table(s, l, t):
+def parse_table(s, loc, tok):
     '''
     Table bookings as bb [headercolor: #cccccc] {
       id integer
@@ -70,25 +71,27 @@ def parse_table(s, l, t):
     }
     '''
     init_dict = {
-        'name': t['name'],
+        'name': tok['name'],
     }
-    if 'settings' in t:
-        init_dict.update(t['settings'])
-    if 'alias' in t:
-        init_dict['alias'] = t['alias'][0]
-    if 'note' in t:
+    if 'schema' in tok:
+        init_dict['schema'] = tok['schema']
+    if 'settings' in tok:
+        init_dict.update(tok['settings'])
+    if 'alias' in tok:
+        init_dict['alias'] = tok['alias'][0]
+    if 'note' in tok:
         # will override one from settings
-        init_dict['note'] = t['note'][0]
-    if'comment_before' in t:
-        comment = '\n'.join(c[0] for c in t['comment_before'])
+        init_dict['note'] = tok['note'][0]
+    if 'indexes' in tok:
+        init_dict['indexes'] = tok['indexes']
+    if 'columns' in tok:
+        init_dict['columns'] = tok['columns']
+    if'comment_before' in tok:
+        comment = '\n'.join(c[0] for c in tok['comment_before'])
         init_dict['comment'] = comment
-    result = Table(**init_dict)
-    for column in t['columns']:
-        result.add_column(column)
-    for index_ in t.get('indexes', []):
-        result.add_index(index_)
+    result = TableBlueprint(**init_dict)
 
     return result
 
 
-table.setParseAction(parse_table)
+table.set_parse_action(parse_table)
